//#define NU32_STANDALONE  // uncomment if program is standalone, not bootloaded
#include "NU32.h"          // plib.h, config bits, constants, funcs for startup and UART

void __ISR(_TIMER_5_VECTOR, IPL4SOFT) Timer5ISR(void) {  // INT step 1: the ISR
  LATDINV = 0b10;             // toggle RD1
  IFS0bits.T5IF = 0;          // clear interrupt flag
}

int main(void) {
  char message[200];
  int i;

  NU32_Startup(); // cache on, min flash wait, interrupts on, LED/button init, UART init

  TRISDbits.TRISD1 = 0;       // make pin 1 of Port D an output

  // plib function to set up and turn on Timer2.  We use the full period, 0xFFFF,
  // for counting external pulses.  In the config info, only T2_SOURCE_EXT and T2_ON
  // are necessary; others for 1:1 prescaler, no gate, and 32-bit mode off are defaults.
  OpenTimer2(T2_SOURCE_EXT | T2_ON | T2_PS_1_1 | T2_GATE_OFF | T2_32BIT_MODE_OFF, 0xFFFF);

  INTDisableInterrupts();     // INT step 2: disable interrupts at CPU
                              // INT step 3: setup Timer45:  T4CON, TMR4, PR4, INT for T5
  T4CON = 1 << 15 | 1 << 3;   //             turn on Timer4 in 32-bit; others default
  PR4 = 39999;                //             set period register for 2 kHz INT
  TMR4 = 0;                   //             initialize count to 0
  IPC5bits.T5IP = 4;          // INT step 4: priority for Timer5 (INT for Timer45)
  IFS0bits.T5IF = 0;          // INT step 5: clear interrupt flag
  IEC0bits.T5IE = 1;          // INT step 6: enable interrupt
  INTEnableSystemMultiVectoredInt();  // INT step 7: enable interrupts at CPU

  while (1) {
    sprintf(message,"Elapsed time:  %5u ms\r\n",TMR2);
    NU32_WriteUART1(message);
    for (i=0; i<10000000; i++); // for loop to 10M; delay print statements
  }
  return 0;
}
