//#define NU32_STANDALONE  // uncomment if program is standalone, not bootloaded
#include "NU32.h"          // plib.h, config bits, constants, funcs for startup and UART

void __ISR(_TIMER_5_VECTOR, IPL4SOFT) Timer5ISR(void) {  // INT step 1: the ISR
  LATDINV = 0b10;             // toggle RD1
  IFS0bits.T5IF = 0;          // clear interrupt flag
}

void __ISR(_TIMER_3_VECTOR, IPL3SOFT) Timer23ISR(void) { // INT step 1: the ISR
  char msg[100];

  IFS0bits.T3IF = 0;          // clear interrupt flag
  sprintf(msg,"The count was %10u, or %10.8f seconds.\r\n",TMR2,TMR2/80000000.0);
  NU32_WriteUART1(msg);
  TMR2 = 0;                   // reset Timer23
}

int main(void) {
  char message[200];
  int i;

  NU32_Startup(); // cache on, min flash wait, interrupts on, LED/button init, UART init
  TRISDbits.TRISD1 = 0;       // make pin 1 of Port D an output

  // plib function to set up and turn on the 32-bit Timer23.  We use the full period,
  // 0xFFFFFFFF, to avoid unnecessary rollovers in timing durations.  In the config
  // we specify only the gated mode and to turn Timer23 on; other defaults are fine.
  OpenTimer23(T23_ON | T23_GATE_ON, 0xFFFFFFFF);

  INTDisableInterrupts();     // INT step 2: disable interrupts at CPU
                              // INT step 3: setup Timer45:  T4CON, TMR4, PR4, INT for T5
  T4CON = 1 << 15 | 1 << 3;   //             turn on Timer4 in 32-bit; others default
  PR4 = 79999999;             //             set period register for 1 Hz INT
  TMR4 = 0;                   //             initialize count to 0
  IPC5bits.T5IP = 4;          // INT step 4: priority for Timer5 (INT for Timer45)
  IPC3bits.T3IP = 3;          //             priority for Timer3 (INT for Timer23)
  IFS0bits.T5IF = 0;          // INT step 5: clear interrupt flag for Timer45
  IFS0bits.T3IF = 0;          //             clear interrupt flag for Timer23
  IEC0bits.T5IE = 1;          // INT step 6: enable interrupt for Timer45
  IEC0bits.T3IE = 1;          //             enable interrupt for Timer23
  INTEnableSystemMultiVectoredInt();  // INT step 7: enable interrupts at CPU

  while (1);
  return 0;
}
